Persistence layer for HNSW indices.
Provides save/load functionality using a versioned binary file format. The format uses a fixed header for quick validation followed by bincode- serialized index data for compact storage of float arrays and adjacency lists.
Functions
- load_
from_ file - Load an
HnswIndexfrom the file atpath. - load_
from_ file_ with_ dimension - Load an
HnswIndexfrom the file atpath, and verify that its dimension matchesexpected_dimension. - save_
to_ file - Save an
HnswIndexto the file atpath.